# FHIR-Aggregator
FHIR client for python3. 

This package provides:
* A low level API for Search/Read operations over multiple FHIR resources.
* Managing client side credentials for FHIR servers.
* Support for broadcasting a query to multiple FHIR servers.
* A high level API for common operations on returned FHIR resources.


## overview

[websequence](https://www.websequencediagrams.com/cgi-bin/cdraw? &s=default) diagram for the high level API:
![image](docs/overview.png)


## Installation

```bash
pip install fhir_aggregator
```

## Usage

```bash
fhir-aggregator 
Usage: fhir-aggregator [OPTIONS] COMMAND [ARGS]...

  FHIR Aggregator Command Line Interface.

Options:
  --help  Show this message and exit.

Commands:
  create-metrics        Creates metrics from search results stored in a...
  normalize-results     Normalizes search results stored in a file.
  register-credentials  Registers a credentials file.
  search-queries        Reads a YAML file of queries and searches all...

```

## Contributing
See [CONTRIBUTING.md](CONTRIBUTING.md) for information on how to contribute to the project.
